const fs = require('node:fs')
const path = require('node:path')
const { snakeCase } = require('change-case')

const svgFolder = path.resolve(__dirname, './svg')

fs.readdirSync(svgFolder).forEach(file => {
  const oldPath = path.resolve(svgFolder, file)

  const normalizedFileName = normalizeName(removeSvgExtension(file))
  const newPath = path.resolve(svgFolder, addSvgExtension(normalizedFileName))

  fs.renameSync(oldPath, newPath)
})

function normalizeName(name) {
  return snakeCase(removeWhitespaces(name))
}

function removeSvgExtension(fileName) {
  if (!fileName.endsWith('.svg')) throw new Error('File must have SVG extension')
  return fileName.replace('.svg', '')
}

function addSvgExtension(fileName) {
  return `${fileName}.svg`
}

function removeWhitespaces(name) {
  return name.replace(/\s+/g, '')
}
